chroot="/var/chroot/mysqld"
testCommandsInsideJail=["safe_mysqld"]
sleepAfterStartCommand=5
processNames=["mysqld"]
testCommandsOutsideJail=["mysql --user=root --socket='/var/chroot/mysqld/var/run/mysqld/mysqld.sock' --exec='show tables' mysql"]
preserve=["/var/lib/mysql",
		  "/var/log/mysql"]
users=["mysql"]
groups=["mysql"]

# Steps:
# 
# Copy the directories in the "preserve" directive to the jail
# with exactly the same ownerships and permissions (cp -RpP)
# Run makejail
# To connect from local clients, keep in mind that the socket
# is now in the jail

# OpenBSD
# preserve=["/var/mysql"]
# testCommandsOutsideJail=["mysql --user=root --socket='/var/chroot/mysqld/var/run/mysql/mysql.sock' --exec='show tables' mysql"]



chroot="/var/chroot/postgresql"
testCommandsInsideJail=["/etc/init.d/postgresql start"]
processNames=["postmaster"]
testCommandsOutsideJail=["su - postgres -c \"psql -c '\z' test\""]
users=["postgres","root"]
groups=["postgres","root"]
preserve=["/dev/log",
		  "/var/lib/postgres"]
cleanJailFirst=0

# The script /etc/init.d/postgresql does some complex things so I've been lazy and
# chrooted it too
#
# start makejail with this configuration file, it won't be able to start the daemon,
# it should display a warning about /dev/log and /proc
#
# overwrite the data files into the jail: cp -a /var/lib/postgres /var/chroot/postgresql/var/lib
#
# configure syslog to also listen to the socket /var/chroot/postgresql/dev/log, restart sysklogd
#
# start makejail again
#
# The deamon now starts fine with chroot /var/chroot/postgresql /etc/init.d/postgresql start
#
# However you can't connect from a client as it doesn't find the socket /var/run/postgresql/.s.PGSQL.5432
# I don't know how to tell psql to use the socket in the jail or TCPIP but there must be a way
#
# create a new startup script /etc/init.d/postgresql_chroot (outside the jail):
#   #!/bin/sh
#   chroot /var/chroot/postgresql /bin/mount /proc $1
#   chroot /var/chroot/postgresql /etc/init.d/postgresql $1

# tested with postgresql 7.1



# Makejail configuration file for sshd
# 
# Created by Javier Fernandez-sanguino Peņa  <jfs@computer.org>
# Thu, 29 Aug 2002 23:44:51 +0200
#
chroot="/var/chroot/sshd"
forceCopy=["/etc/ssh/ssh_host*","/etc/ssh/sshd*","/etc/ssh/moduli",
	"/etc/pam.conf","/etc/security/*","/etc/pam.d/ssh","/etc/pam.d/other",
	"/etc/hosts","/etc/nsswitch.conf",
	"/var/run/sshd","/lib/security/*",
	"/etc/shells", "/etc/nologin","/etc/environment","/etc/motd",
	"/etc/shadow","/etc/hosts*",
	"/bin/*sh", "/lib/libnss*",
	"/dev/pt*","/dev/ttyp[0-9]*"]

# Remove this if you want to make configuration changes *outside* of the
# chroot environment
# preserve=["/etc/","/home/","/dev/"]
# otherwise just do this:
preserve=["/dev/","/home"]

# Besides the sshd user (needed after 3.4p1) any user which is going to
# be granted access to the ssh daemon should be added to 'users' and
# 'groups'.
userFiles=["/etc/passwd","/etc/shadow"]
groupFiles=["/etc/group","/etc/gshadow"]
users=["sshd"]
groups=["sshd"]

testCommandsInsideJail=["start-stop-daemon --start --quiet --pidfile /var/run/sshd.pid --exec /usr/sbin/sshd"]
testCommandsOutsideJail=["ssh localhost"]

processNames=["sshd"]

# Changes to do to jail sshd:
# 1.- start makejail with this configuration file
# it might not be able to start the daemon since the daemon tries to
# access /dev/log (handled by syslogd)
#
# 2.- In init.d's startup script (/etc/init.d/sshd):
# replace "start-stop-daemon ..." with "chroot /var/chroot/sshd start-stop-daemon ..."
#
# 3.- configure syslog to also listen to the socket /var/chroot/sshd/dev/log, 
# restart sysklogd. 
# (for Debian) This can be done by changing the SYSLOGD option in
# /etc/init.d/syslogd to
# SYSLOGD="-p /dev/log -p /var/chroot/sshd/dev/log"
#
# 4.- Create the user directories under /home and copy their files there
#
# 5.- Users will not be able to a single thing in the restricted environment
#     besides running their shell. You will have to add some utilities
#     to the chrooted environement. Try adding this to the configuration
# packages=["fileutils"]
#     You can add any other Debian packages you want users to have access
#     to.
# 
# WARNING: this configuration file has only been slightly tested. not yet thoroughly tested yet.



chroot="/var/chroot/bind"
forceCopy=["/etc/bind/*","/var/cache/bind"]
preserve=["/var/cache/bind"]
testCommandsInsideJail=["start-stop-daemon --start --quiet --pidfile /var/run/named.pid --exec /usr/sbin/named"]
processNames=["named"]
testCommandsOutsideJail=["dig @127.0.0.1 yahoo.com",
						 "dig @127.0.0.1 -x 127.0.0.1",
						 "dig @127.0.0.1 -x 198.186.203.20",
						 "ping -c 1 www.google.com"]

# start makejail with this configuration file, it won't be able to start the daemon,
# it should display a warning about /dev/log and /proc
#
# In the startup script:
# replace "start-stop-daemon ..." with "chroot /var/chroot/bind start-stop-daemon ..."
#
# handle /proc (mount when it starts, unmount when it stops):
# chroot /var/chroot/apache /bin/mount /proc
#
# configure syslog to also listen to the socket /var/chroot/bind/dev/log, restart sysklogd

# tested successfully with bind 9.2.0 on Debian woody



# Tested on GNU/Linux Debian sid
# mldonkey from cvs compiled and run in /home/alain/mldonkey
# Set personals string values in this file and the wrapper code.

# First you have to create a wrapper to execute mldonkey as non-root
# See for example mldonkey_wrapper. at the bottom of this file, you
# can compile it with "gcc -o mldonkey_wrapper mldonkey_wrapper.c"
# It's better than su and sudo which are suid programs
#
# Make sure you can run the wrapper as root outside the jail and that everything
# works fine
#
# Run makejail using this configuration file
#
# Then you can start mldonkey with this command as root :
# chroot /var/chroot/mldonkey /home/alain/mldonkey/mldonkey_wrapper
#
# If you system uses /proc and if there is a comment about it at the
# end of makejail output you must create it (for example at each system startup)

chroot="/var/chroot/mldonkey"

testCommandsInsideJail=["/home/alain/mldonkey/mldonkey_wrapper"]
processNames=["mldonkey"]

preserve=["/dev/log",
		  "/home/alain/mldonkey/*.ini"]

forceCopy=["/home/alain/mldonkey/*.ini"]

testCommandsOutsideJail=["su - alain -c /home/alain/mldonkey/mldonkey_gui"]

# The users which should be allowed to run mldonkey
# Make sure they can execute /usr/local/mldonkey before building the jail

users=["alain"]
groups=["alain"]

keepStraceOutputs=1

# Below is the code of mldonkey_wrapper.c
#
##include <errno.h>
##include <unistd.h>
##include <pwd.h>
#
#main (ac,av)
#{
#  int status;
#  struct passwd *pnew;
#  char **newav;
#
#  pnew=getpwnam("alain");
#
#  status=setregid(pnew->pw_gid,pnew->pw_gid);
#  if (status != 0)
#        {
#          printf("wrapper.c: error in setgeuid, errno = %d\n",errno);
#          return;
#        }
#
#  status=setreuid(pnew->pw_uid,pnew->pw_uid);
#  if (status != 0)
#        {
#          printf("wrapper.c: error in setreuid, errno = %d\n",errno);
#          return;
#        }
#
#  printf("Root privileged dropped successfully\n");
#
#  chdir("/home/alain/mldonkey");
#  printf("Changed working directory to /home/alain\n");
#
#  newav=(char**)malloc(6);
#  newav[0]="mldonkey";
#  newav[1]="-ask_for_gui";
#  newav[2]="false";
#  newav[3]="-start_gui";
#  newav[4]="false";
#  newav[5]=0;
#
#  execv("/home/alain/mldonkey/mldonkey",newav);
#
#  free(newav);
#
#}



chroot="/var/chroot/apache"
testCommandsInsideJail=["/usr/sbin/apachectl start"]
processNames=["apache"]

# Eventually append here the commands which access some services
# such as cgi or php scripts, database access, ...
testCommandsOutsideJail=["wget -r --spider http://localhost/",
						 "lynx --source https://localhost/"]

preserve=["/var/www",
		  "/var/log/apache",
		  "/dev/log"]
users=["www-data"]
groups=["www-data"]

# launch makejail
#
# copy the documents and the logs to the jail
# cp -Rp /var/www /var/chroot/apache/var
# cp -Rp /var/log/apache/*.log /var/chroot/apache/var/log/apache
#
# configure syslog to also listen to the socket /var/chroot/apache/dev/log, restart sysklogd
#
# In the startup script /etc/init.d/apache, just change the paths
# of variables used from outside the jail:
# APACHECTL="chroot /var/chroot/apache /usr/sbin/apachectl" (remove the line which tests -f $APACHECTL)
# PIDFILE=/var/chroot/apache/var/run/$NAME.pid
# CONF=/var/chroot/apache/etc/apache/httpd.conf
#
# handle /proc in the script (mount when it starts, unmount when it stops):
# chroot /var/chroot/apache /bin/mount /proc
#
# apache can fail starting though apachectl doesn't fail, see error.log in the chroot
#

# tested successfully with apache 1.3.22 on Debian woody
# (also with php4, mysql and a search engine)

# OpenBSD
#processNames=["httpd"]
#users=["nobody"]
#groups=["nogroup","www"]
